@@ -1,5 +1,5 @@
 /*
- * Icon configuration file for freeBSD
+ * Icon configuration file for freeBSD on Intel
  */
 
 #define UNIX 1
@@ -14,4 +14,3 @@
 
 #define CComp "gcc"
 #define COpts "-O2"
-#define LinkLibs " -lm"
