@@ -7,7 +7,7 @@
 #
 #	Author:   Gregg M. Townsend
 #
-#	Date:     October 3, 1995
+#	Date:     November 17, 1997
 #
 ############################################################################
 #
@@ -33,7 +33,7 @@
 */
 
 #include "icall.h"
-#include <malloc.h>
+#include <stdlib.h>
 
 #define DEFLENGTH 100
 
