@@ -7,7 +7,7 @@
 #
 #	Author:   Gregg M. Townsend
 #
-#	Date:     October 3, 1995
+#	Date:     November 17, 1997
 #
 ############################################################################
 #
@@ -48,6 +48,7 @@
 */
 
 #include "icall.h"
+#include <string.h>
 
 #define F_LTL 0x100	/* little-endian */
 #define F_BIG 0x200	/* big-endian */
