@@ -42,14 +42,14 @@ static int list_ser;
 struct tend_desc *tend;
 
 #ifdef MSWindows
-char *getenv(char *s)
-{
-static char tmp[1537];
-DWORD rv;
-rv = GetEnvironmentVariable(s, tmp, 1536);
-if (rv > 0) return tmp;
-return NULL;
-}
+   char *getenv(char *s)
+   {
+   static char tmp[1537];
+   DWORD rv;
+   rv = GetEnvironmentVariable(s, tmp, 1536);
+   if (rv > 0) return tmp;
+      return NULL;
+   }
 #endif						/* MSWindows */
 
 /*
@@ -77,7 +77,7 @@ unsigned char allchars[256] = {
 /*
  * fatalerr - disable error conversion and call run-time error routine.
  */
-novalue fatalerr(n, v)
+void fatalerr(n, v)
 int n;
 dptr v;
    {
@@ -129,7 +129,7 @@ double val;
    AlcFixBlk(blk, b_real, T_Real)
 
 #ifdef Double
-/* access real values one word at a time */
+   /* access real values one word at a time */
    { int *rp, *rq;
      rp = (int *) &(blk->realval);
      rq = (int *) &val;
@@ -143,11 +143,19 @@ double val;
    return blk;
    }
 
+char *alcstr(char *s, int len)
+{
+   register char *s1;
+
+   s1 = (char *)alloc((msize)(len + 1));
+   return strncpy(s1, s, len);
+}
+
 /*
  * initalloc - initialization routine to allocate memory regions
  */
 
-novalue initalloc(codesize)
+void initalloc(codesize)
 word codesize;
    {
    static char dummy[1];	/* dummy static region */
@@ -177,7 +185,7 @@ word codesize;
    }
 
 
-novalue err_msg(n, v)
+void err_msg(n, v)
 int n;
 dptr v;
 {
@@ -378,7 +386,7 @@ dptr d;
  *  making q a descriptor for the resulting string.
  */
 
-static novalue itos(num, dp, s)
+static void itos(num, dp, s)
 C_integer num;
 dptr dp;
 char *s;
@@ -466,7 +474,7 @@ union numeric *result;
    num = 0L;
    while (isalnum(c)) {
 #if !EBCDIC
-#define tonum(c)	(isdigit(c) ? (c)-'0' : 10+(((c)|(040))-'a'))
+   #define tonum(c)	(isdigit(c) ? (c)-'0' : 10+(((c)|(040))-'a'))
 #endif
       c = tonum(c);
       if (c >= r)
@@ -494,50 +502,13 @@ union numeric *result;
  * rtos - convert the real number n into a string using s as a buffer and
  *  making a descriptor for the resulting string.
  */
-novalue rtos(n, dp, s)
+void rtos(n, dp, s)
 double n;
 dptr dp;
 char *s;
    {
-
-   s++; 			/* leave room for leading zero */
-/*
- * The following code is operating-system dependent [@rconv.01]. Convert real
- *  number to string.
- *
- * If IconGcvt is defined, icon_gcvt() is actually called, due to a #define
- *  in config.h.
- */
-#undef gcvt
-
-#if PORT
-   gcvt(n, Precision, s);
-Deliberate Syntax Error
-#endif					/* PORT */
-
-#if HIGHC_386
-   sprintf(s,"%.*g", Precision, n);
-#else					/* HIGHC_386 */
-#if AMIGA || ARM || ATARI_ST || MSDOS || OS2 || UNIX || VMS
-   gcvt(n, Precision, s);
-#endif                                  /* AMIGA || ARM || ATARI_ST || ... */
-#endif					/* HIGHC_386 */
-
-#if MACINTOSH
-   sprintf(s,"%.20g",n);
-#endif					/* MACINTOSH */
-
-#if VM || MVS
-   sprintf(s,"%.*g", Precision, n);
-   {
-     char *ep = strstr(s, "e+");
-     if (ep) memmove(ep+1, ep+2, strlen(ep+2)+1);
-   }
-#endif					/* VM || MVS */
-
-/*
- * End of operating-system specific code.
- */
+   s++; 				/* leave room for leading zero */
+   sprintf(s, "%.*g", Precision, n + 0.0);  /* format string; +0.0 avoids -0 */
    
    /*
     * Now clean up possible messes.
@@ -550,7 +521,7 @@ Deliberate Syntax Error
       }
    else if (strcmp(s, "-0.0") == 0)	/* negative zero */
       s++;
-   else if (!index(s, '.') && !index(s,'e') && !index(s,'E'))
+   else if (!strchr(s, '.') && !strchr(s,'e') && !strchr(s,'E'))
          strcat(s, ".0");		/* if no decimal point or exp. */
    if (s[strlen(s) - 1] == '.')		/* if decimal point is at end ... */
       strcat(s, "0");
@@ -884,10 +855,38 @@ unsigned long ConsoleFlags = 0;			 /* Console flags */
 extern int ConsolePause;
 extern FILE *flog;
 
+
+void closelogfile()
+{
+   if (flog) {
+      extern char *lognam;
+      extern char tmplognam[];
+      FILE *flog2;
+      int i;
+      fclose(flog);
+
+      /*
+       * copy to the permanent file name
+       */
+      if ((flog = fopen(tmplognam, "r")) &&
+	  (flog2 = fopen(lognam, "w"))) {
+	 while ((i = getc(flog)) != EOF)
+	    putc(i, flog2);
+	 fclose(flog);
+	 fclose(flog2);
+	 remove(tmplognam);
+	 }
+
+      free(lognam);
+      flog = NULL;
+      }
+}
+
+
 /*
  * c_exit(i) - flush all buffers and exit with status i.
  */
-novalue c_exit(i)
+void c_exit(i)
 int i;
 {
    char *msg = "Strike any key to close console...";
@@ -934,8 +933,21 @@ int i;
       }
 
 #if !MACINTOSH
-#undef exit
+   #undef exit
 #endif					/* MACINTOSH */
    exit(i);
 }
+
+
+int strncasecmp(char *s1, char *s2, int n)
+{
+   int i, j;
+   for(i=0;i<n;i++) {
+      j = tolower(s1[i]) - tolower(s2[i]);
+      if (j) return j;
+      if (s1[i] == '\0') return 0; /* terminate if both at end-of-string */
+      }
+   return 0;
+}
+
 #endif					/* ConsoleWindow */
