@@ -1,7 +1,6 @@
 /*
  * Routines to read a data base of run-time information.
  */
-#include <ctype.h>
 #include "../h/gsupport.h"
 #include "../h/version.h"
 #include "icontype.h"
@@ -29,19 +28,19 @@
 /*
  * prototypes for static functions.
  */
-hidden int            cmp_1_pre  Params((int p1, int p2));
-hidden struct il_code *db_abstr  Params((noargs));
-hidden novalue         db_case   Params((struct il_code *il, int num_cases));
-hidden novalue         db_err3   Params((int fatal,char *s1,char *s2,char *s3));
-hidden int             db_icntyp Params((noargs));
-hidden struct il_c    *db_ilc    Params((noargs));
-hidden struct il_c    *db_ilcret Params((int il_c_type));
-hidden struct il_code *db_inlin  Params((noargs));
-hidden struct il_code *db_ilvar  Params((noargs));
-hidden int             db_rtflg  Params((noargs));
-hidden int             db_tndtyp Params((noargs));
-hidden struct il_c    *new_ilc   Params((int il_c_type));
-hidden novalue          quoted   Params((int delim));
+static int            cmp_1_pre  (int p1, int p2);
+static struct il_code *db_abstr  (void);
+static void         db_case   (struct il_code *il, int num_cases);
+static void         db_err3   (int fatal,char *s1,char *s2,char *s3);
+static int             db_icntyp (void);
+static struct il_c    *db_ilc    (void);
+static struct il_c    *db_ilcret (int il_c_type);
+static struct il_code *db_inlin  (void);
+static struct il_code *db_ilvar  (void);
+static int             db_rtflg  (void);
+static int             db_tndtyp (void);
+static struct il_c    *new_ilc   (int il_c_type);
+static void          quoted   (int delim);
 
 extern char *progname;   /* name of program using this module */
 
@@ -157,7 +156,7 @@ char **lrgintflg;
 /*
  * db_close - close data base.
  */
-novalue db_close()
+void db_close()
    {
    if (fclose(db) != 0)
       db_err2(0, "cannot close", dbname);
@@ -348,7 +347,7 @@ int oper_typ;
 /*
  * db_code - read the RTL code for the body of an operation.
  */
-novalue db_code(ip)
+void db_code(ip)
 struct implement *ip;
    {
    register int c;
@@ -452,7 +451,7 @@ struct implement *ip;
  */
 static struct il_code *db_inlin()
    {
-   struct il_code *il;
+   struct il_code *il = NULL;
    register int c;
    int i;
    int indx;
@@ -513,9 +512,9 @@ static struct il_code *db_inlin()
          switch (getc(db)) {
             case 'a': {
                char prfx3;
-               int ret_val;
+               int ret_val = 0;
                int ret_flag;
-               int rslt;
+               int rslt = 0;
                int num_sbuf;
                int num_cbuf;
 
@@ -860,7 +859,7 @@ static int db_rtflg()
 /*
  * db_case - get the cases for a type_case statement from the data base.
  */
-static novalue db_case(il, num_cases)
+static void db_case(il, num_cases)
 struct il_code *il;
 int num_cases;
    {
@@ -935,7 +934,7 @@ static struct il_code *db_ilvar()
  */
 static struct il_code *db_abstr()
    {
-   struct il_code *il;
+   struct il_code *il = NULL;
    register int c;
    word typcd;
    word indx;
@@ -1077,7 +1076,7 @@ static struct il_c *db_ilc()
                               db_chstr("$cg", "oto");
                               *nxtp = new_ilc(ILC_CGto);
 #ifdef MultiThread
-#undef code
+   #undef code
 #endif					/* MultiThead */
                               (*nxtp)->code[0] = db_ilc();
                               c = getc(db);
@@ -1235,13 +1234,15 @@ static struct il_c *db_ilc()
          return NULL;
       }
    db_err1(1, "expected C code of the form $c ... $e or nil");
+   /*NOTREACHED*/
+   return 0;	/* avoid gcc warning */
    }
 
 /*
  * quoted - get the string for a quoted literal. The first quote mark
  *  has been read.
  */
-static novalue quoted(delim)
+static void quoted(delim)
 int delim;
    {
    register int c;
@@ -1294,19 +1295,21 @@ static int db_tndtyp()
    c = getc(db);
    SkipWhSp(c)
    switch (c) {
-       case 'b':
-          db_chstr("b", "lkptr");
-          return TndBlk;          /* tended block pointer */
-       case 'd':
-          db_chstr("d", "esc");
-          return TndDesc;         /* tended descriptor */
-       case 's':
-          db_chstr("s", "tr");
-          return TndStr;          /* tended string */
+      case 'b':
+         db_chstr("b", "lkptr");
+         return TndBlk;          /* tended block pointer */
+      case 'd':
+         db_chstr("d", "esc");
+         return TndDesc;         /* tended descriptor */
+      case 's':
+         db_chstr("s", "tr");
+         return TndStr;          /* tended string */
       default:
-          db_err1(1, "expected blkptr, desc, or str");
-          /* NOTREACHED */
+         db_err1(1, "expected blkptr, desc, or str");
+         /* NOTREACHED */
       }
+   /* NOTREACHED */
+   return 0;	/* avoid gcc warning */
    }
 
 /*
@@ -1379,6 +1382,7 @@ static int db_icntyp()
       }
    db_err1(1, "invalid type code");
    /* NOTREACHED */
+   return 0;	/* avoid gcc warning */
    }
 
 /*
@@ -1420,7 +1424,7 @@ int size;
  * db_dscrd - discard an implementation up to $end, skipping the in-line
  *   RTL code.
  */
-novalue db_dscrd(ip)
+void db_dscrd(ip)
 struct implement *ip;
    {
    char state;  /* how far along we are at recognizing $end */
@@ -1462,7 +1466,7 @@ struct implement *ip;
  * db_chstr - we are expecting a specific string. We may already have
  *   read a prefix of it.
  */
-novalue db_chstr(prefix, suffix)
+void db_chstr(prefix, suffix)
 char *prefix;
 char *suffix;
    {
@@ -1544,7 +1548,7 @@ struct implement **tbl;
  *   the range 0-9 and a-z, at least one of which is a digit.
  *
  */
-novalue nxt_pre(pre, nxt, n)
+void nxt_pre(pre, nxt, n)
 char *pre;
 char *nxt;
 int n;
@@ -1553,7 +1557,7 @@ int n;
 
    if (nxt[0] == '\0') {
       fprintf(stderr, "out of unique prefixes\n");
-      exit(ErrorExit);
+      exit(EXIT_FAILURE);
       }
 
    /*
@@ -1656,7 +1660,7 @@ int p2;
 /*
  * db_err1 - print a data base error message in the form of 1 string.
  */
-novalue db_err1(fatal, s)
+void db_err1(fatal, s)
 int fatal;
 char *s;
    {
@@ -1666,13 +1670,13 @@ char *s;
       fprintf(stderr, "warning, ");
    fprintf(stderr, "data base \"%s\", line %d - %s\n", dbname, dbline, s);
    if (fatal)
-      exit(ErrorExit);
+      exit(EXIT_FAILURE);
    }
 
 /*
  * db_err2 - print a data base error message in the form of 2 strings.
  */
-novalue db_err2(fatal, s1, s2)
+void db_err2(fatal, s1, s2)
 int fatal;
 char *s1;
 char *s2;
@@ -1684,13 +1688,13 @@ char *s2;
    fprintf(stderr, "data base \"%s\", line %d - %s %s\n", dbname, dbline, s1,
       s2);
    if (fatal)
-      exit(ErrorExit);
+      exit(EXIT_FAILURE);
    }
 
 /*
  * db_err3 - print a data base error message in the form of 3 strings.
  */
-static novalue db_err3(fatal, s1, s2, s3)
+static void db_err3(fatal, s1, s2, s3)
 int fatal;
 char *s1;
 char *s2;
@@ -1703,5 +1707,5 @@ char *s3;
    fprintf(stderr, "data base \"%s\", line %d - %s %s%s\n", dbname, dbline, s1,
       s2, s3);
    if (fatal)
-      exit(ErrorExit);
+      exit(EXIT_FAILURE);
    }
