@@ -111,10 +111,6 @@
  *  can be cast as #ifdef Coexpr.
  */
 
-/*
- *  The mysterious Garden of Eden; not supported under the compiler.
- */
-
 #ifndef NoCoexpr
    #undef Coexpr
    #define Coexpr
@@ -154,10 +150,6 @@
    #define MultiThread
 #endif					/* EventMon */
 
-#ifndef RefPath
-   #define RefPath BinPath
-#endif					/* RefPath */
-
 /*
  * Names for standard environment variables.
  * The standard names are used unless they are overridden.
@@ -253,7 +245,7 @@
    #endif				/* NoIconify */
 
    #ifndef ICONC_XLIB
-      #define ICONC_XLIB "-lX11"
+      #define ICONC_XLIB "-L/usr/X11R6/lib -lX11"
    #endif				/* ICONC_XLIB */
 
    #ifdef ConsoleWindow
@@ -585,10 +577,6 @@ Deliberate Syntax Error
    #define PPDirectives {"passthru", PpKeep},
 #endif					/* PPDirectives */
 
-#ifndef NoRanlib
-   #define Ranlib
-#endif					/* NoRanlib */
-
 #ifndef EventMon
    #if IntBits == 16
       #define NoSrcColumnInfo
@@ -669,93 +657,6 @@ Deliberate Syntax Error
 
 #endif					/* COMPILER */
 
-#ifndef IconOptions
-
-   #if AMIGA
-      #define IconOptions "C:ELS:Tce:f:n:o:p:r:stuv:x"
-   #endif				/* AMIGA */
-
-   #if ARM || MPW || UNIX || VMS
-      #define IconOptions "C:ELS:Tce:f:mn:o:p:r:stuv:x"
-   #endif				/* ARM || MPW || UNIX || VMS */
-
-   #if THINK_C
-      #define IconOptions "C:ELS:XITce:f:mn:o:p:r:stuv:x"
-   #endif				/* THINK_C */
-
-   #if MSDOS
-      #ifdef MSWindows
-         #define IconOptions "C:ELS:XITce:f:mn:o:p:qr:stuv:x"
-      #else				/* MSWindows */
-         #if SCCX_MX
-            #define IconOptions "C:ELS:AXITce:f:mn:o:p:r:stuv:x"
-         #else				/* SCCX_MX */
-            #define IconOptions "C:ELS:XITce:f:mn:o:p:r:stuv:x"
-         #endif				/* SCCX_MX */
-      #endif				/* MSWindows */
-   #endif				/* MSDOS */
-
-   #if OS2
-      #define IconOptions "C:ELS:Tce:f:in:o:p:r:stuv:x"
-   #endif				/* OS2 */
-
-#endif					/* IconOptions */
-
-#if EBCDIC
-   #define CUsage "<-C C-comp> <-T> <-c> <-f{adelns}> <-n{acest}>\n\
- <-o ofile> <-p C-opts> <-r runtime> <-s> <-t> <-u> <-v i>"
-#else                                   /* EBCDIC */
-   #ifndef CUsage
-      #if UNIX
-#define CUsage "[-C C-comp] [-E] [-T] [-c] [-f{adelns}] [-m] [-n{acest}]\n\
- [-o ofile] [-p C-opts] [-r runtime] [-s] [-t] [-u] [-v i]"
-   #else				/* UNIX */
-#define CUsage "[-C C-comp] [-E] [-T] [-c] [-f{adelns}] [-n{acest}]\n\
- [-o ofile] [-p C-opts] [-r runtime] [-s] [-t] [-u] [-v i]"
-      #endif				/* UNIX */
-   #endif				/* CUsage */
-#endif					/* EBCDIC */
-
-#ifndef TUsage
-
-   #if EBCDIC
-      #define TUsage "<-cstu> <-fs> <-e efile> <-o ofile>"
-   #endif				/* EBCDIC */
-
-   #if AMIGA
-      #define TUsage "[-cstuE] [-fs] [-e efile] [-o ofile]"
-   #endif				/* AMIGA */
-
-   #if ARM || UNIX
-      #define TUsage "[-cmstuE] [-fs] [-e efile] [-o ofile]"
-   #endif				/* ARM || UNIX */
-
-   #if MPW
-      #define TUsage "[-cstuE] [-fs] [-e efile] [-o ofile]"
-   #endif				/* MPW */
-
-   #if THINK_C
-      #define TUsage "[-cmstuE] [-fs] [-e efile] [-o ofile]"
-   #endif				/* THINK_C */
-
-   #if OS2
-      #define TUsage "[-cistuEI] [-fs] [-e efile] [-o ofile]"
-   #endif				/* OS2 */
-
-   #if MVS || VM
-      #define TUsage "<-cstuE> <-fs> <-e efile> <-o ofile>"
-   #endif				/* MVS || VM */
-
-   #if MSDOS
-      #if SCCX_MX
-         #define TUsage "[-cstuAEIX] [-fs] [-e efile] [-o ofile]"
-      #else				/* SCCX_MX */
-         #define TUsage "[-cstuEIX] [-fs] [-e efile] [-o ofile]"
-      #endif				/* SCCX_MX */
-   #endif				/* MSDOS */
-
-#endif					/* TUsage */
-
 #if UNIX
    #undef Header
    #define Header
