@@ -3,35 +3,35 @@
  */
 
 #ifdef MacGraph
-#include "::h:macgraph.h"
+   #include "::h:macgraph.h"
 #endif					/* MacGraph */
 
 #ifdef XWindows
-#include "../h/xwin.h"
+   #include "../h/xwin.h"
 #endif					/* XWindows */
 
 #ifdef PresentationManager
-#include "../h/pmwin.h"
+   #include "../h/pmwin.h"
 #endif					/* PresentationManager */
 
 #ifdef MSWindows
-#include "../h/mswin.h"
+   #include "../h/mswin.h"
 #endif					/* MSWindows */
 
 #ifndef MAXXOBJS
-#define MAXXOBJS 256
+   #define MAXXOBJS 256
 #endif					/* MAXXOBJS */
 
 #ifndef DMAXCOLORS
-#define DMAXCOLORS 256
+   #define DMAXCOLORS 256
 #endif					/* DMAXCOLORS */
 
 #ifndef MAXCOLORNAME
-#define MAXCOLORNAME 40
+   #define MAXCOLORNAME 40
 #endif					/* MAXCOLORNAME */
 
 #ifndef MAXFONTWORD
-#define MAXFONTWORD 40
+   #define MAXFONTWORD 40
 #endif					/* MAXFONTWORD */
 
 #define DEFAULTFONTSIZE 14
@@ -85,9 +85,6 @@
  * mode bits for the Icon window context (as opposed to X context)
  */
 
-#ifdef XWindows
-#define ISZOMBIE(w)     ((w)->window->bits & 1)
-#endif					/* XWindows */
 #define ISINITIAL(w)    ((w)->window->bits & 1)
 #define ISINITIALW(ws)   ((ws)->bits & 1)
 #define ISCURSORON(w)   ((w)->window->bits & 2)
@@ -101,20 +98,7 @@
 #define ISEXPOSED(w)    ((w)->window->bits & 256)
 #define ISCEOLON(w)     ((w)->window->bits & 512)
 #define ISECHOON(w)     ((w)->window->bits & 1024)
-#ifdef PresentationManager
-#define ISMINPEND(w)    ((w)->window->bits & 2048)
-#define ISMINPENDW(ws)   ((ws)->bits & 2048)
-#endif					/* PresentationManager */
-#ifdef MSWindows
-#define ISTOBEHIDDEN(ws)  ((ws)->bits & 4096)
-#endif					/* MSWindows */
 
-#ifdef XWindows
-#define SETZOMBIE(w)    ((w)->window->bits |= 1)
-#endif					/* XWindows */
-#ifdef PresentationManager
-#define SETINITIAL(w)   ((w)->window->bits |= 1)
-#endif					/* PresentationManager */
 #define SETCURSORON(w)  ((w)->window->bits |= 2)
 /* 4 is available */
 #define SETMAPPED(w)   ((w)->window->bits |= 4)
@@ -125,20 +109,7 @@
 #define SETEXPOSED(w)   ((w)->window->bits |= 256)
 #define SETCEOLON(w)    ((w)->window->bits |= 512)
 #define SETECHOON(w)    ((w)->window->bits |= 1024)
-#ifdef PresentationManager
-#define SETMINPEND(w)   ((w)->window->bits |= 2048)
-#endif					/* PresentationManager */
-#ifdef MSWindows
-#define SETTOBEHIDDEN(ws)  ((ws)->bits |= 4096)
-#endif					/* MSWindows */
 
-#ifdef XWindows
-#define CLRZOMBIE(w)    ((w)->window->bits &= ~1)
-#endif					/* XWindows */
-#ifdef PresentationManager
-#define CLRINITIAL(w)   ((w)->window->bits &= ~1)
-#define CLRINITIALW(w)  ((w)->bits &= ~1)
-#endif					/* PresentationManager */
 #define CLRCURSORON(w)  ((w)->window->bits &= ~2)
 #define CLRMAPPED(w)    ((w)->window->bits &= ~4)
 #define CLRREVERSE(w)   ((w)->context->bits &= ~8)
@@ -148,12 +119,28 @@
 #define CLREXPOSED(w)   ((w)->window->bits &= ~256)
 #define CLRCEOLON(w)    ((w)->window->bits &= ~512)
 #define CLRECHOON(w)    ((w)->window->bits &= ~1024)
+
+#ifdef XWindows
+   #define ISZOMBIE(w)     ((w)->window->bits & 1)
+   #define SETZOMBIE(w)    ((w)->window->bits |= 1)
+   #define CLRZOMBIE(w)    ((w)->window->bits &= ~1)
+#endif					/* XWindows */
+
 #ifdef PresentationManager
-#define CLRMINPEND(w)   ((w)->window->bits &= ~2048)
-#define CLRMINPENDW(w)  ((w)->bits &= ~2048)
+   #define ISMINPEND(w)    ((w)->window->bits & 2048)
+   #define ISMINPENDW(ws)   ((ws)->bits & 2048)
+   #define SETINITIAL(w)   ((w)->window->bits |= 1)
+   #define SETMINPEND(w)   ((w)->window->bits |= 2048)
+   #define CLRINITIAL(w)   ((w)->window->bits &= ~1)
+   #define CLRINITIALW(w)  ((w)->bits &= ~1)
+   #define CLRMINPEND(w)   ((w)->window->bits &= ~2048)
+   #define CLRMINPENDW(w)  ((w)->bits &= ~2048)
 #endif					/* PresentationManager */
+
 #ifdef MSWindows
-#define CLRTOBEHIDDEN(ws)  ((ws)->bits &= ~4096)
+   #define ISTOBEHIDDEN(ws)  ((ws)->bits & 4096)
+   #define SETTOBEHIDDEN(ws)  ((ws)->bits |= 4096)
+   #define CLRTOBEHIDDEN(ws)  ((ws)->bits &= ~4096)
 #endif					/* MSWindows */
 
 
@@ -180,7 +167,7 @@ typedef struct _wfont {
   short     fontNum;
   Style     fontStyle;
   int       fontSize;
-  FontInfo  fInfo;              /* I-173 */
+  FontInfo  fInfo;			/* I-173 */
 #endif					/* MacGraph */
 #ifdef XWindows
   char	      *	name;			/* name for WAttrib and fontsearch */
@@ -188,8 +175,8 @@ typedef struct _wfont {
   XFontStruct *	fsp;			/* X font pointer */
 #endif					/* XWindows */
 #ifdef PresentationManager
-/* XXX replace this HUGE structure with single fields later - when we know
-   conclusively which ones we need */
+   /* XXX replace this HUGE structure with single fields later - when we know
+      conclusively which ones we need */
   FONTMETRICS	metrics;		/* more than you ever wanted to know */
 #endif					/* PresentationManager */
 #ifdef MSWindows
@@ -295,15 +282,15 @@ typedef struct _wdisplay {
 #define IS_MARKER               4               /* unused for now */
 
 typedef struct _lclIdentifier {
-  SHORT idtype;         /* type of the id, either font or pattern */
-  SHORT refcount;       /* reference count, when < 1, deleted */
-  union {
-     wfont font;    /* font info */
-     HBITMAP   hpat;    /* pattern bitmap handle */
-     } u;
-  struct _lclIdentifier *next,          /* dbl linked list */
+   SHORT idtype;         /* type of the id, either font or pattern */
+   SHORT refcount;       /* reference count, when < 1, deleted */
+   union {
+      wfont font;    /* font info */
+      HBITMAP   hpat;    /* pattern bitmap handle */
+      } u;
+   struct _lclIdentifier *next,          /* dbl linked list */
                         *previous;
-  } lclIdentifier;
+} lclIdentifier;
 
 #endif					/* PresentationManager */
 
@@ -315,53 +302,69 @@ typedef struct _lclIdentifier {
  * Contexts are allocated out of a global array in rwinrsrc.c.
  */
 typedef struct _wcontext {
-  int		refcount;
-  int		serial;			/* serial # */
-  struct _wcontext *previous, *next;
-  int		clipx, clipy, clipw, cliph;
-  char		*patternname;
-  wfp		font;
-  int		dx, dy;
-  int		fillstyle;
-  int		drawop;
-  double	gamma;			/* gamma correction value */
-  int		bits;			/* context bits */
+   int		refcount;
+   int		serial;			/* serial # */
+   struct _wcontext *previous, *next;
+   int		clipx, clipy, clipw, cliph;
+   char		*patternname;
+   wfp		font;
+   int		dx, dy;
+   int		fillstyle;
+   int		drawop;
+   double	gamma;			/* gamma correction value */
+   int		bits;			/* context bits */
 #ifdef MacGraph
-  ContextPtrType   contextPtr;
+   ContextPtrType   contextPtr;
 #endif					/* MacGraph */
 #ifdef XWindows
-  wdp		display;
-  GC		gc;			/* X graphics context */
-  wclrp		fg, bg;
-  int		linestyle;
-  int		linewidth;
-  int		leading;		/* inter-line leading */
+   wdp		display;
+   GC		gc;			/* X graphics context */
+   wclrp	fg, bg;
+   int		linestyle;
+   int		linewidth;
+   int		leading;		/* inter-line leading */
 #endif					/* XWindows */
 #ifdef PresentationManager
-  /* attribute bundles */
-  CHARBUNDLE	charBundle;		/* text attributes */
-  LINEBUNDLE	lineBundle;		/* line/arc attributes */
-  AREABUNDLE	areaBundle;		/* polygon attributes... */
-  IMAGEBUNDLE	imageBundle;		/* attributes use in blit of mono bms */
-  LONG 		fntLeading;		/* external leading for font - user */
-  SHORT		currPattern;		/* id of current pattern */
-  LONG		numDeps;		/* number of window dependants */
-  LONG		maxDeps;		/* maximum number of deps in current table */
-  struct _wstate **depWindows;           /* array of window dependants */
+   /* attribute bundles */
+   CHARBUNDLE	charBundle;		/* text attributes */
+   LINEBUNDLE	lineBundle;		/* line/arc attributes */
+   AREABUNDLE	areaBundle;		/* polygon attributes... */
+   IMAGEBUNDLE	imageBundle;		/* attributes use in blit of mono bms */
+   LONG 	fntLeading;		/* external leading for font - user */
+   SHORT	currPattern;		/* id of current pattern */
+   LONG		numDeps;		/* number of window dependants */
+   LONG		maxDeps;		/* max number of deps in curr table */
+   struct _wstate **depWindows;		/* array of window dependants */
 #endif					/* PresentationManager */
 #ifdef MSWindows
-  LOGPEN	pen;
-  LOGPEN	bgpen;
-  LOGBRUSH	brush;
-  LOGBRUSH	bgbrush;
-  HRGN          cliprgn;
-  HBITMAP	pattern;
-  SysColor	fg, bg;
-  char		*fgname, *bgname;
-  int		leading, bkmode;
+   LOGPEN	pen;
+   LOGPEN	bgpen;
+   LOGBRUSH	brush;
+   LOGBRUSH	bgbrush;
+   HRGN          cliprgn;
+   HBITMAP	pattern;
+   SysColor	fg, bg;
+   char		*fgname, *bgname;
+   int		leading, bkmode;
 #endif					/* MSWindows*/
 } wcontext, *wcp;
 
+/*
+ * Native facilities include the following child controls (windows) that
+ * persist on the canvas and intercept various events.
+ */
+#ifdef MSWindows
+   #define CHILD_BUTTON 0
+   #define CHILD_SCROLLBAR 1
+   #define CHILD_EDIT 2
+typedef struct childcontrol {
+   int  type;				/* what kind of control? */
+   HWND win;				/* child window handle */
+   HFONT font;
+   char *id;				/* child window string id */
+} childcontrol;
+#endif					/* MSWindows */
+
 /*
  * "Window state" includes the actual X window and references to a large
  * number of resources allocated on a per-window basis.  Windows are
@@ -392,9 +395,9 @@ typedef struct _wstate {
   char		*cursorname;
   struct descrip filep, listp;		/* icon values for this window */
 #ifdef MacGraph
-  WindowPtr theWindow;      /* pointer to the window */
-  PicHandle windowPic;      /* handle to backing pixmap */
-  GWorldPtr offScreenGWorld;  /* offscreen graphics world */
+  WindowPtr theWindow;			/* pointer to the window */
+  PicHandle windowPic;			/* handle to backing pixmap */
+  GWorldPtr offScreenGWorld;		/* offscreen graphics world */
   CGrafPtr   origPort;
   GDHandle  origDev;
   PixMapHandle offScreenPMHandle;
@@ -458,9 +461,16 @@ typedef struct _wstate {
   HBITMAP	pix;			/* backing bitmap */
   HBITMAP	iconpix;		/* backing bitmap */
   HBITMAP	initialPix;		/* backing bitmap */
+  HBITMAP	theOldPix;
   int		hasCaret;
   HCURSOR	curcursor;
   HCURSOR	savedcursor;
+  HMENU		menuBar;
+  int		nmMapElems;
+  char **       menuMap;
+  HWND		focusChild;
+  int           nChildren;
+  childcontrol *child;
 #endif					/* MSWindows */
 } wstate, *wsp;
 
@@ -500,7 +510,7 @@ typedef struct {
  * Gamma Correction value to compensate for nonlinear monitor color response
  */
 #ifndef GammaCorrection
-#define GammaCorrection 2.5
+   #define GammaCorrection 2.5
 #endif					/* GammaCorrection */
 
 /*
