@@ -86,8 +86,6 @@ static	void	setexe	(char *fname);
 FILE *infile;				/* input file (.u1 or .u2) */
 FILE *outfile;				/* interpreter code output file */
 
-extern char *ofile;			/* output file name */
-
 #ifdef DeBugLinker
    FILE *dbgfile;			/* debug file */
    static char dbgname[MaxFileName];	/* debug file name */
@@ -337,8 +335,6 @@ char *outname;
    strcat(script, "        \n\f\n" + ((int)(strlen(script) + 4) % 8));
    hdrsize = strlen(script) + 1;	/* length includes \0 at end */
    fwrite(script, hdrsize, 1, outfile);	/* write header */
-#else                                   /* AMIGA */
-   char cmd[MaxPath + 100], script[2 * MaxPath + 200];
 #endif                                  /* AMIGA */
 
 #if NT
@@ -349,6 +345,7 @@ char *outname;
     * fails, rather than fall through and start executing machine code
     * as if it were batch commands.
     */
+   char script[2 * MaxPath + 200];
    sprintf(script,
            "@echo off\r\n%s %%0 %%1 %%2 %%3 %%4 %%5 %%6 %%7 %%8 %%9\r\n",
            ((iconxloc!=NULL)?iconxloc:"wiconx"));
@@ -360,10 +357,29 @@ char *outname;
    fwrite(script, hdrsize, 1, outfile);	/* write header */
 #endif					/* NT */
 #if UNIX
-   sprintf(cmd, "exec \"${ICONX-%s}\" \"$0\"", iconxloc);
-   sprintf(script, "%s   0) %s;;\n   *) %s \"$@\";;%s\n",
-      "#!/bin/sh\n\ncase $# in\n", cmd, cmd,
-      "\nesac\n\n[executable Icon binary follows]");
+   /*
+    *  Generate a shell header that searches for iconx in this order:
+    *     a.  location specified by ICONX environment variable
+    *         (if specified, this MUST work, else the script exits)
+    *     b.  iconx in same directory as executing binary
+    *     c.  location specified in script
+    *         (as generated by icont or as patched later)
+    *     d.  iconx in $PATH
+    *
+    *  The ugly ${1+"$@"} is a workaround for non-POSIX handling
+    *  of "$@" by some shells in the absence of any arguments.
+    *  Thanks to the Unix-haters handbook for this trick.
+    */
+   char script[2 * MaxPath + 300];
+   sprintf(script, "%s\n%s%-72s\n%s\n\n%s\n%s\n%s\n%s\n\n%s\n",
+      "#!/bin/sh",
+      "IXBIN=", iconxloc,
+      "IXLCL=`echo $0 | sed 's=[^/]*$=iconx='`",
+      "[ -n \"$ICONX\" ] && exec \"$ICONX\" $0 ${1+\"$@\"}",
+      "[ -x $IXLCL ] && exec $IXLCL $0 ${1+\"$@\"}",
+      "[ -x $IXBIN ] && exec $IXBIN $0 ${1+\"$@\"}",
+      "exec iconx $0 ${1+\"$@\"}",
+      "[executable Icon binary follows]");
    strcat(script, "        \n\f\n" + ((int)(strlen(script) + 4) % 8));
    hdrsize = strlen(script) + 1;	/* length includes \0 at end */
    fwrite(script, hdrsize, 1, outfile);	/* write header */
