@@ -16,10 +16,14 @@
 Deliberate Syntax Error
 #endif					/* PORT */
 
-#if AMIGA || ATARI_ST
+#if AMIGA
+   /* nothing is needed */
+#endif					/* AMIGA */
+
+#if ATARI_ST
    /* something may be needed */
 Deliberate Syntax Error
-#endif					/* AMIGA || ATARI_ST */
+#endif					/* ATARI_ST */
 
 #if MACINTOSH
    /* nothing is needed */
@@ -60,10 +64,10 @@ char *_style = "tso:";
 /*
  * Prototypes for static functions.
  */
-hidden novalue define_opt   Params((char *s, int len, struct token *dflt));
-hidden novalue do_directive Params((char *s));
-hidden novalue mac_opts     Params((char *opt_lst, char **opt_args));
-hidden novalue undef_opt    Params((char *s, int len));
+static void define_opt   (char *s, int len, struct token *dflt);
+static void do_directive (char *s);
+static void mac_opts     (char *opt_lst, char **opt_args);
+static void undef_opt    (char *s, int len);
 
 struct src dummy;
 
@@ -71,7 +75,7 @@ struct src dummy;
  * init_preproc - initialize all parts of the preprocessor, establishing
  *  the primary file as the current source of tokens.
  */
-novalue init_preproc(fname, opt_lst, opt_args)
+void init_preproc(fname, opt_lst, opt_args)
 char *fname;
 char *opt_lst;
 char **opt_args;
@@ -96,7 +100,7 @@ char **opt_args;
  *  systems will have some predefined macros which are not dependent on
  *  options; establish them also.
  */
-static novalue mac_opts(opt_lst, opt_args)
+static void mac_opts(opt_lst, opt_args)
 char *opt_lst;
 char **opt_args;
    {
@@ -113,10 +117,18 @@ char **opt_args;
 Deliberate Syntax Error
 #endif					/* PORT */
 
-#if AMIGA || ATARI_ST
+#if AMIGA
+   do_directive("#define AMIGA 1\n");
+#if __SASC
+   do_directive("#define __SASC 1\n");
+   do_directive("#define LATTICE 0\n");
+#endif                                  /* __SASC */
+#endif					/* AMIGA */
+
+#if ATARI_ST
    /* something may be needed */
 Deliberate Syntax Error
-#endif					/* AMIGA || ATARI_ST  ... */
+#endif					/* ATARI_ST */
 
 #if MACINTOSH
    /* nothing is needed */
@@ -576,10 +588,14 @@ Deliberate Syntax Error
 Deliberate Syntax Error
 #endif					/* PORT */
 
-#if AMIGA || ATARI_ST
+#if AMIGA
+   /* nothing is needed */
+#endif					/* AMIGA */
+
+#if ATARI_ST
    /* something may be needed */
 Deliberate Syntax Error
-#endif					/* AMIGA || ATARI_ST */
+#endif					/* ATARI_ST */
 
 #if MACINTOSH
    /* nothing is needed */
@@ -833,7 +849,7 @@ Deliberate Syntax Error
  * str_src - establish a string, given by a character pointer and a length,
  *  as the current source of tokens.
  */
-novalue str_src(src_name, s, len)
+void str_src(src_name, s, len)
 char *src_name;
 char *s;
 int len;
@@ -866,7 +882,7 @@ int len;
  *  directives separated by new-lines and execute them. This done
  *  by preprocessing the string.
  */
-static novalue do_directive(s)
+static void do_directive(s)
 char *s;
    {
    str_src("<initialization>", s, (int)strlen(s));
@@ -878,7 +894,7 @@ char *s;
  * undef_opt - take the argument to a -U option and, if it is valid,
  *  undefine it.
  */
-static novalue undef_opt(s, len)
+static void undef_opt(s, len)
 char *s;
 int len;
    {
@@ -906,7 +922,7 @@ int len;
  * define_opt - take an argument to a -D option and, if it is valid, perform
  *  the requested definition.
  */
-static novalue define_opt(s, len, dflt)
+static void define_opt(s, len, dflt)
 char *s;
 int len;
 struct token *dflt;
