@@ -7,22 +7,22 @@
 /*
  * prototypes for static functions. 
  */
-hidden struct il_code *abstrcomp Params((struct node *n, int indx_stor,
-                                    int chng_stor, int escapes));
-hidden novalue         abstrsnty Params((struct token *t, int typcd,
-                                   int indx_stor, int chng_stor));
-hidden int             body_anlz Params((struct node *n, int *does_break,
-                                   int may_mod, int const_cast, int all));
-hidden struct il_code *body_fnc  Params((struct node *n));
-hidden novalue         chkrettyp Params((struct node *n));
-hidden novalue         chng_ploc Params((int typcd, struct node *src));
-hidden novalue         cnt_bufs  Params((struct node *cnv_typ));
-hidden struct il_code *il_walk   Params((struct node *n));
-hidden struct il_code *il_var    Params((struct node *n));
-hidden int             is_addr   Params((struct node *dcltor, int modifier));
-hidden novalue         lcl_tend  Params((struct node *n));
-hidden int             mrg_abstr Params((int sum, int typ));
-hidden int             strct_typ Params((struct node *typ, int *is_reg));
+static struct il_code *abstrcomp (struct node *n, int indx_stor,
+                                    int chng_stor, int escapes);
+static void         abstrsnty (struct token *t, int typcd,
+                                   int indx_stor, int chng_stor);
+static int             body_anlz (struct node *n, int *does_break,
+                                   int may_mod, int const_cast, int all);
+static struct il_code *body_fnc  (struct node *n);
+static void         chkrettyp (struct node *n);
+static void         chng_ploc (int typcd, struct node *src);
+static void         cnt_bufs  (struct node *cnv_typ);
+static struct il_code *il_walk   (struct node *n);
+static struct il_code *il_var    (struct node *n);
+static int             is_addr   (struct node *dcltor, int modifier);
+static void         lcl_tend  (struct node *n);
+static int             mrg_abstr (int sum, int typ);
+static int             strct_typ (struct node *typ, int *is_reg);
 
 static int body_ret; /* RetInt, RetDbl, and/or RetOther for current body */
 static int ret_flag; /* DoesFail, DoesRet, and/or DoesSusp for current body */
@@ -58,7 +58,7 @@ extern char *src_file_nm;
  * in_line - place in the data base in-line code for an operation and
  *   produce C functions for body statements.
  */
-novalue in_line(n)
+void in_line(n)
 struct node *n;
    {
    struct sym_entry *sym;
@@ -744,7 +744,7 @@ int escapes;
    switch (n->nd_id) {
       case PrefxNd:
          switch (t->tok_id) {
-            case Type:
+            case TokType:
                /*
                 * type( <variable> )
                 */
@@ -883,7 +883,7 @@ int escapes;
  * abstrsnty - do some sanity checks on how this type is being used in
  *  an abstract type computation.
  */
-static novalue abstrsnty(t, typcd, indx_stor, chng_stor)
+static void abstrsnty(t, typcd, indx_stor, chng_stor)
 struct token *t;
 int typcd;
 int indx_stor;
@@ -1299,13 +1299,14 @@ int all;          /* input flag: need all information about operation */
       }
    err1("rtt internal error detected in function body_anlz()");
    /* NOTREACHED */
+   return 0;  /* avoid gcc warning */
    }
 
 /*
  *  lcl_tend  - allocate any tended variables needed in this body or inline
  *   statement.
  */
-static novalue lcl_tend(n)
+static void lcl_tend(n)
 struct node *n;
    {
    struct sym_entry *sym;
@@ -1364,7 +1365,7 @@ struct node *n;
  * chkrettyp - check type of return to see if it is a C integer or a
  *  C double and make note of what is found.
  */
-static novalue chkrettyp(n)
+static void chkrettyp(n)
 struct node *n;
    {
    if (n->nd_id == PrefxNd && n->tok != NULL) {
@@ -1558,7 +1559,7 @@ struct node *n;
          fprintf(out_file, "double ");
          break;
       case RetNoVal:
-         fprintf(out_file, "novalue ");
+         fprintf(out_file, "void ");
          break;
       }
    fprintf(out_file, " %c%c%c%c_%s(", uc_letter, prfx1, prfx2, prfx3,
@@ -1837,7 +1838,7 @@ int *is_reg;
          case Extern:
             errt2(typ->tok, "declare {...} should not contain ",
                typ->tok->image);
-         case Register:
+         case TokRegister:
             *is_reg = 1;
             return 0;
          case TypeDefName:
@@ -1901,13 +1902,14 @@ int modifier;
       }
    err1("rtt internal error detected in function is_addr()");
    /* NOTREACHED */
+   return 0;  /* avoid gcc warning */
    }
 
 /*
  * chgn_ploc - if this is an "in-place" conversion to a C value, change
  *  the "location" of the parameter being converted.
  */
-static novalue chng_ploc(typcd, src)
+static void chng_ploc(typcd, src)
 int typcd;
 struct node *src;
    {
@@ -1938,7 +1940,7 @@ struct node *src;
  * cnt_bufs - See if we need to allocate a string or cset buffer for
  *  this conversion.
  */
-static novalue cnt_bufs(cnv_typ)
+static void cnt_bufs(cnv_typ)
 struct node *cnv_typ;
    {
    if (cnv_typ->nd_id == PrimryNd)
