@@ -2,20 +2,23 @@
  * errmsg.r -- err_msg, irunerr, drunerr
  */
 
-hidden novalue err_txt Params((int n));
-
 #ifdef PresentationManager
 extern MRESULT_N_EXPENTRY RuntimeErrorDlgProc(HWND, ULONG, MPARAM, MPARAM);
 HAB HInterpAnchorBlock;
 #endif					/* PresentationManager */
 
+#if AMIGA && __SASC
+extern void PostClip(char *file, int line, int number, char *text);
+extern void CallARexx(char *script);
+#endif					/* AMIGA && __SASC */
+
 extern struct errtab errtab[];		/* error numbers and messages */
 
 /*
  * err_msg - print run-time error message, performing trace back if required.
  *  This function underlies the rtt runerr() construct.
  */
-novalue err_msg(n, v)
+void err_msg(n, v)
 int n;
 dptr v;
 {
@@ -78,23 +81,28 @@ dptr v;
       }
 
    if (!debug_info)
-      c_exit(ErrorExit);
+      c_exit(EXIT_FAILURE);
 
    if (pfp == NULL) {		/* skip if start-up problem */
       if (dodump)
          abort();
-      c_exit(ErrorExit);
+      c_exit(EXIT_FAILURE);
       }
 
    fprintf(stderr, "Traceback:\n");
-   tracebk(pfp, argp);
+   tracebk(pfp, glbl_argp);
    fflush(stderr);
 
 
    if (dodump)
       abort();
 
-   c_exit(ErrorExit);
+#if AMIGA && __SASC
+   PostClip(findfile(ipc.opnd), findline(ipc.opnd), k_errornumber, k_errortext);
+   CallARexx(IconxRexx);
+#endif					/* AMIGA && __SASC */
+
+   c_exit(EXIT_FAILURE);
 #else					/* PresentationManager */
 
   if (pfp != NULL) {
@@ -117,7 +125,7 @@ dptr v;
   if (dodump)
     abort();
 
-  c_exit(ErrorExit);
+  c_exit(EXIT_FAILURE);
 #endif					/* PresentationManager */
 }
 
@@ -125,7 +133,7 @@ dptr v;
  * irunerr - print an error message when the offending value is a C_integer
  *  rather than a descriptor.
  */
-novalue irunerr(n, v)
+void irunerr(n, v)
 int n;
 C_integer v;
    {
@@ -140,7 +148,7 @@ C_integer v;
  * drunerr - print an error message when the offending value is a C double
  *  rather than a descriptor.
  */
-novalue drunerr(n, v)
+void drunerr(n, v)
 int n;
 double v;
    {
