@@ -21,7 +21,6 @@ function{1} delete(s,x)
          body {
             register uword hn;
             register union block **pd;
-            union block *bp;     /* does not need to be tended. */
             int res;
 
             hn = hash(&x);
@@ -41,7 +40,6 @@ function{1} delete(s,x)
 	    }
       table:
          body {
-            union block *bp;     /* does not need to be tended. */
             register union block **pd;
             register uword hn;
             int res;
@@ -445,13 +443,13 @@ end
 /*
  * c_push - C-level, nontending push operation
  */
-int c_push(l, val)
+void c_push(l, val)
 dptr l;
 dptr val;
 {
    register word i;
    register struct b_lelem *bp; /* does not need to be tended */
-   static two = 2;		/* some compilers generate bad code for
+   static int two = 2;		/* some compilers generate bad code for
 				   division by a constant that's a power of 2*/
    /*
     * Point bp at the first list-element block.
@@ -535,7 +533,7 @@ function{1} push(x, vals[n])
       dptr dp;
       register word i, val, num;
       register struct b_lelem *bp; /* does not need to be tended */
-      static two = 2;		/* some compilers generate bad code for
+      static int two = 2;	/* some compilers generate bad code for
 				   division by a constant that's a power of 2*/
 
       if (n == 0) {
@@ -630,7 +628,7 @@ struct descrip *val;
 {
    register word i;
    register struct b_lelem *bp;  /* does not need to be tended */
-   static two = 2;		/* some compilers generate bad code for
+   static int two = 2;		/* some compilers generate bad code for
 				   division by a constant that's a power of 2*/
 
    /*
@@ -715,7 +713,7 @@ function{1} put(x, vals[n])
       dptr dp;
       register word i, val, num;
       register struct b_lelem *bp;  /* does not need to be tended */
-      static two = 2;		/* some compilers generate bad code for
+      static int two = 2;	/* some compilers generate bad code for
 				   division by a constant that's a power of 2*/
       if (n == 0) {
 	 dp = &nulldesc;
