@@ -9,92 +9,27 @@
 #include "../h/header.h"
 #include "../h/opdefs.h"
 
-#if SCCX_MX
-/*
- * The setsize program will replace "frog" with the file size of
- * iconx.exe.  The file size is used to scan to the end of the file
- * to see if a .icx file has been concatenated to the end.
- */
-setint_t    sizevar = {'f','r','o','g'};
-int  thisIsIconx;
-char settingsname[260];
-
-/* This sets the stack size so it runs in a Windows DOS box */
-unsigned _stack = 100000;
-
-#endif  /* SCCX_MX */
-
-/*
- * Prototypes.
- */
 void	icon_setup	(int argc, char **argv, int *ip);
 
-#ifdef MacGraph
-void MacMain (int argc, char **argv);
-void ToolBoxInit (void);
-void MenuBarInit (void);
-void MouseInfoInit (void);
-int GetArgs (char **argv);
-#endif					/* MacGraph */
-
-/*
- * The following code is operating-system dependent [@imain.01].  Declarations
- *   that are system-dependent.
- */
-
-#if PORT
-   /* probably needs something more */
-Deliberate Syntax Error
-#endif					/* PORT */
-
-#if AMIGA && __SASC
-extern int _WBargc;     /* These are filled in by auto-initialization */
-extern char **_WBargv;  /* code in rlocal.r                           */
-char __stdiowin[] = "CON:10/40/640/200/IconX Console Window";
-   /* These override environment variables if set from ToolTypes. */
-extern uword WBstrsize;
-extern uword WBblksize;
-extern uword WBmstksize;
-#endif					/* AMIGA && __SASC */
-
-#if MACINTOSH
-#if MPW
-int NoOptions = 0;
-#endif					/* MPW */
-#endif					/* MACINTOSH */
-
-#if ARM || ATARI_ST || MSDOS || MVS || VM || OS2 || UNIX\
-   || VMS
-   /* nothing needed */
-#endif					/* ARM || ATARI_ST ... */
-
-/*
- * End of operating-system specific code.
- */
-
 extern int set_up;
 
-/*
- * A number of important variables follow.
- */
-
-#ifndef MultiThread
-int n_globals = 0;			/* number of globals */
-int n_statics = 0;			/* number of statics */
-#endif					/* MultiThread */
-
-
-/*
- * Initial icode sequence. This is used to invoke the main procedure with one
- *  argument.  If main returns, the Op_Quit is executed.
- */
 word istart[4];
 int mterm = Op_Quit;
 
+#ifndef MultiThread
+   int n_globals = 0;			/* number of globals */
+   int n_statics = 0;			/* number of statics */
+#endif					/* MultiThread */
+
+
 
+#ifdef MSWindows
+/*
+ * Special initialization under MS Windows.
+ */
+
 FILE *finredir, *fouredir, *ferredir;
 
-#ifdef MSWindows
 void detectRedirection()
 {
    struct stat sb;
@@ -234,30 +169,30 @@ char tmplognam[128];
 void MSStartup(HINSTANCE hInstance, HINSTANCE hPrevInstance)
    {
    WNDCLASS wc;
-#ifdef ConsoleWindow
-   extern FILE *flog;
-
-   /*
-    * Select log file name.  Might make this a command-line option.
-    * Default to "WICON.LOG".  The log file is used by Wi to report
-    * translation errors and jump to the offending source code line.
-    */
-   if ((lognam = getenv("WICONLOG")) == NULL)
-      lognam = "WICON.LOG";
-   remove(lognam);
-   lognam = strdup(lognam);
-   flog = fopen(tmpnam(tmplognam), "w");
-
-   if (flog == NULL) {
-      syserr("unable to open logfile");
-      }
-#endif					/* ConsoleWindow */
+   #ifdef ConsoleWindow
+      extern FILE *flog;
+   
+      /*
+       * Select log file name.  Might make this a command-line option.
+       * Default to "WICON.LOG".  The log file is used by Wi to report
+       * translation errors and jump to the offending source code line.
+       */
+      if ((lognam = getenv("WICONLOG")) == NULL)
+         lognam = "WICON.LOG";
+      remove(lognam);
+      lognam = strdup(lognam);
+      flog = fopen(tmpnam(tmplognam), "w");
+   
+      if (flog == NULL) {
+         syserr("unable to open logfile");
+         }
+   #endif				/* ConsoleWindow */
    if (!hPrevInstance) {
-#if NT
-      wc.style = CS_HREDRAW | CS_VREDRAW;
-#else					/* NT */
-      wc.style = 0;
-#endif					/* NT */
+      #if NT
+         wc.style = CS_HREDRAW | CS_VREDRAW;
+      #else				/* NT */
+         wc.style = 0;
+      #endif				/* NT */
       wc.lpfnWndProc = WndProc;
       wc.cbClsExtra = 0;
       wc.cbWndExtra = 0;
@@ -297,129 +232,17 @@ int_PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
 }
 #define main iconx
 #endif					/* MSWindows */
-
-#if OS2
-int stubexe;
-void os2main(int stubflag, int argc, char**argv); /* Prototype OS2main */
-void os2main(stubflag, argc, argv)
-int stubflag;
-#else					/* OS2 */
-#ifdef MacGraph
-MouseInfoType gMouseInfo;
-PaletteHandle gPal;
-long gNumColors;
-Boolean gDone;
-char *cmlArgs;
-StringHandle textHandle;
-
-void MacMain (argc, argv)
-#else					/* MacGraph */
+
+/*
+ * Initial icode sequence. This is used to invoke the main procedure with one
+ *  argument.  If main returns, the Op_Quit is executed.
+ */
 int main(argc, argv)
-#endif					/* MacGraph */
-#endif					/* OS2 */
 int argc;
 char **argv;
    {
    int i, slen;
 
-#if SCCX_MX
-    int     ctrlbrk;
-    FILE*   selfPtr;
-    int     new_argc;
-    char    **new_argv;
-    struct FIND *p;
-
-    strcpy(settingsname, argv[0]);
-    selfPtr = fopen( settingsname, "rb");
-    fseek( selfPtr, 0L, SEEK_END);
-    if( ftell( selfPtr) > sizevar.value)
-    {
-        ++argc;
-        --argv;
-        thisIsIconx = 1;
-    }
-    else
-        thisIsIconx = 0;
-
-    fclose( selfPtr);
-
-    /*
-     *  Expand wildcard file names:
-     *      Replace command line arguments with the file names that match
-     *      wildcard specifications.
-     *      Leave arguments that don't match file names as they are so the
-     *      icon program can deal with them.
-     */
-    new_argc = 1;
-    new_argv = malloc( new_argc * sizeof(char *));
-    new_argv[0] = malloc( (strlen(settingsname)+1) * sizeof(char));
-    memcpy( new_argv[0], settingsname, strlen(settingsname)+1);
-    for( i=1; i<argc; ++i)
-    {
-        if( (p = findfirst( argv[i], 0)) != NULL)
-        {
-            while( p)
-            {
-                new_argc++;
-                new_argv = realloc( new_argv, new_argc * sizeof(char *));
-                new_argv[new_argc-1] = malloc( (strlen(p->name)+1) * sizeof(char));
-                memcpy( new_argv[new_argc-1], p->name, strlen(p->name)+1);
-                p = findnext();
-            }
-        }
-        else
-        {
-            new_argc++;
-            new_argv = realloc( new_argv, new_argc * sizeof(char *));
-            new_argv[new_argc-1] = malloc( (strlen(argv[i])+1) * sizeof(char));
-            memcpy( new_argv[new_argc-1], argv[i], strlen(argv[i])+1);
-        }
-    }
-
-    if( new_argc == 1)
-    {
-        /* Add a null string to accommodate code in icon_setup() */
-        new_argv = realloc( new_argv, new_argc+1 * sizeof(char *));
-        new_argv[new_argc] = malloc( sizeof(char));
-        strcpy( new_argv[new_argc], "");
-    }
-
-    argv = new_argv;
-    argc = new_argc;
-
-#if 0
-    if( argc < 2)
-    {
-    syntax error!
-    The Symantec license agreement requires you to include a copyright
-    notice in your program.  This is a good place for it.
-
-        fprintf( stderr,
-            "\nCopyright (c) 1996, Your Name, Your City, Your State.\n");
-        exit(1);
-    }
-#endif
-    ctrlbrk = dos_get_ctrl_break();
-    dos_set_ctrl_break(1);   /* Ensure proper Ctrl-C operation */
-#endif  /* SCCX_MX */
-
-#if AMIGA
-#if AZTEC_C
-   struct Process *FindTask();
-   struct Process *Process = FindTask(0L);
-   ULONG stacksize = *((ULONG *)Process->pr_ReturnAddr);
-
-   if (stacksize < ICONXMINSTACK) {
-      fprintf(stderr,"Iconx needs \"stack %d\" to run\n",ICONXMINSTACK);
-      exit(-1);
-      }
-#endif					/* AZTEC_C */
-#endif					/* AMIGA */
-
-#if SASC
-   quiet(1);                    /* suppress C library diagnostics */
-#endif					/* SASC */
-
 #ifdef MultiThread
    /*
     * Look for MultiThread programming environment in which to execute
@@ -452,114 +275,25 @@ char **argv;
 
    ipc.opnd = NULL;
 
+#if UNIX
+   /*
+    *  Append to FPATH the bin directory from which iconx was executed.
+    */
+   {
+      char *p, *q, buf[1000];
+      p = getenv("FPATH");
+      q = relfile(argv[0], "/..");
+      sprintf(buf, "FPATH=%s %s", (p ? p : "."), (q ? q : "."));
+      putenv(buf);
+      }
+#endif
+
    /*
     * Setup Icon interface.  It's done this way to avoid duplication
     *  of code, since the same thing has to be done if calling Icon
     *  is enabled.
     */
 
-#ifdef CRAY
-   argv[0] = "iconx";
-#endif					/* CRAY */
-
-#if OS2
-   if (stubflag) {  /* Invoked as a direct executable */
-      stubexe = 1;
-      icon_init(argv[0],&argc, argv);
-      argc += 2;
-      argv -= 2;
-      }
-   else {
-      stubexe = 0;
-      icon_setup(argc, argv, &i);
-      if (i < 0) {
-	 argc++;
-	 argv--;
-	 i++;
-	 }
-      while (i--) {			    /* skip option arguments */
-	 argc--;
-	 argv++;
-	 }
-
-      if (argc <= 1)
-	 error(NULL, "An icode file was not specified.\nExecution cannot proceed.");
-      /*
-       * Call icon_init with the name of the icode file to execute.	    [[I?]]
-       */
-
-      icon_init(argv[1], &argc, argv);
-      }
-#else					/* OS2 */
-
-#if AMIGA && __SASC
-   if (argc == 0) {         /* argc == 0 flags a Workbench startup */
-      struct DiskObject *dob;
-      char *filename;
-      char *errorname;
-      char *size;
-      long newout;
-      long newerr;
-
-      if(dob = GetDiskObject(_WBargv[1])) {
-         if(dob->do_ToolTypes){
-         /* First get redirects from ToolTypes.
-            With a Workbench startup, stdin points to the console
-            window opened in MODE_NEWFILE, while stdout and stderr
-            share a pointer to the console window opened with
-            MODE_OLDFILE.  The close flag is on stderr. */
-
-            errorname = FindToolType(dob->do_ToolTypes,"STDERR");
-
-            if (errorname != NULL && strcmp(errorname, "-") == 0) {
-               if (filename = FindToolType(dob->do_ToolTypes,"STDOUT")) {
-                  if ( newout = Open(filename, MODE_NEWFILE) ) {
-                     Close(__ufbs[1].ufbfh);
-                     __ufbs[1].ufbfh = newout;
-                     __ufbs[2].ufbfh = newout;
-                     }
-                  }
-               }
-
-            else {
-               if (errorname != NULL) {
-                  if ( newerr = Open(errorname, MODE_NEWFILE) ) {
-                     __ufbs[2].ufbfh = newerr;
-                     __ufbs[1].ufbflg |= UFB_CLO;
-                     }
-                  }
- 
-               if (filename = FindToolType(dob->do_ToolTypes,"STDOUT")) {
-                  if (newout = Open(filename, MODE_NEWFILE) ) {
-                     if (newerr) Close(__ufbs[1].ufbfh);
-                     __ufbs[1].ufbfh = newout;
-                     __ufbs[1].ufbflg |= UFB_CLO;
-                     }
-                  }
-               }
-
-            if (filename = FindToolType(dob->do_ToolTypes,"STDIN"))
-               freopen(filename, "r", stdin);
-
-         /* Set sizes from Tooltypes. */
-            if (size = FindToolType(dob->do_ToolTypes,"STRSIZE"))
-               WBstrsize = strtoul(size,NULL,10);
-
-            if (size = FindToolType(dob->do_ToolTypes,"BLKSIZE"))
-               WBblksize = strtoul(size,NULL,10);
-
-            if (size = FindToolType(dob->do_ToolTypes,"MSTKSIZE"))
-               WBmstksize = strtoul(size,NULL,10);
-
-            }
-         FreeDiskObject(dob);
-         }
-
-      argc = _WBargc;
-      argv = _WBargv;
-      }
-#endif					/* AMIGA && __SASC */
-
    icon_setup(argc, argv, &i);
 
    if (i < 0) {
@@ -581,8 +315,6 @@ char **argv;
     */
    icon_init(argv[1], &argc, argv);
 
-#endif					/* OS2 */
-
    /*
     *  Point sp at word after b_coexpr block for &main, point ipc at initial
     *	icode segment, and clear the gfp.
@@ -663,15 +395,11 @@ char **argv;
     *  c_exit() is called to wrap things up.
     */
 
-#ifdef CoProcesses
-   codisp();    /* start up co-expr dispatcher, which will call interp */
-#else					/* CoProcesses */
-   interp(0,(dptr)NULL);                        /*      [[I?]] */
-#endif					/* CoProcesses */
-
-#if SCCX_MX
-    dos_set_ctrl_break(ctrlbrk);   /* Restore original Ctrl-C operation */
-#endif
+   #ifdef CoProcesses
+      codisp();    /* start up co-expr dispatcher, which will call interp */
+   #else				/* CoProcesses */
+      interp(0,(dptr)NULL);                        /*      [[I?]] */
+   #endif				/* CoProcesses */
 
    c_exit(EXIT_SUCCESS);
    return 0;
@@ -686,136 +414,82 @@ char **argv;
 int *ip;
    {
 
-#ifdef TallyOpt
-   extern int tallyopt;
-#endif					/* TallyOpt */
+   #ifdef TallyOpt
+      extern int tallyopt;
+   #endif				/* TallyOpt */
 
    *ip = 0;			/* number of arguments processed */
 
-#ifdef ExecImages
-   if (dumped) {
+   #ifdef ExecImages
+      if (dumped) {
+         /*
+          * This is a restart of a dumped interpreter.  Normally, argv[0] is
+          *  iconx, argv[1] is the icode file, and argv[2:(argc-1)] are the
+          *  arguments to pass as a list to main().  For a dumped interpreter
+          *  however, argv[0] is the executable binary, and the first argument
+          *  for main() is argv[1].  The simplest way to handle this is to
+          *  back up argv to point at argv[-1] and increment argc, giving the
+          *  illusion of an additional argument at the head of the list.  Note
+          *  that this argument is never referenced.
+          */
+         argv--;
+         argc++;
+         (*ip)--;
+         }
+   #endif				/* ExecImages */
+
+   #if NT
       /*
-       * This is a restart of a dumped interpreter.  Normally, argv[0] is
-       *  iconx, argv[1] is the icode file, and argv[2:(argc-1)] are the
-       *  arguments to pass as a list to main().  For a dumped interpreter
-       *  however, argv[0] is the executable binary, and the first argument
-       *  for main() is argv[1].  The simplest way to handle this is to
-       *  back up argv to point at argv[-1] and increment argc, giving the
-       *  illusion of an additional argument at the head of the list.  Note
-       *  that this argument is never referenced.
+       * if we didn't start with nticonx.exe or wiconx.exe, backup one
+       * so that our icode filename is argv[1].
        */
-      argv--;
-      argc++;
-      (*ip)--;
-      }
-#endif					/* ExecImages */
-
-#if NT
-   /*
-    * if we didn't start with nticonx.exe or wiconx.exe, backup one
-    * so that our icode filename is argv[1].
-    */
-   {
-   char tmp[256], *t2;
-   int len = 0;
-   strcpy(tmp, argv[0]);
-   t2 = tmp;
-   while (*t2) {
-      *t2 = tolower(*t2);
-      t2++;
-      len++;
-      }
-
-   /*
-    * if argv[0] is not a reference to our interpreter, take it as the
-    * name of the icode file, and back up for it.
-    */
-#ifdef MSWindows
-   if (!((len == 6 && !strcmp(tmp+len-6, "wiconx")) ||
-         (len > 6 && !strcmp(tmp+len-7, "\\wiconx")) ||
-         (len == 10 && !strcmp(tmp+len-10, "wiconx.exe")) ||
-         (len > 10 && !strcmp(tmp+len-11, "\\wiconx.exe")))) {
-#else					/* MSWindows */
-   if (!((len == 7 && !strcmp(tmp+len-7, "nticonx")) ||
-         (len > 7 && !strcmp(tmp+len-8, "\\nticonx")) ||
-         (len == 11 && !strcmp(tmp+len-11, "nticonx.exe")) ||
-         (len > 11 && !strcmp(tmp+len-12, "\\nticonx.exe")))) {
-#endif					/* MSWindows */
-      argv--;
-      argc++;
-      (*ip)--;
-      }
-   }
-#endif					/* NT */
-
-#ifdef MaxLevel
-   maxilevel = 0;
-   maxplevel = 0;
-   maxsp = 0;
-#endif					/* MaxLevel */
-
-#if MACINTOSH
-#if MPW
-   InitCursorCtl(NULL);
-   /*
-    * To support the icode and iconx interpreter bundled together in
-    * the same file, we might have to use this code file as the icode
-    * file, too.  We do this if the command name is not 'iconx'.
-    */
-   {
-   char *p,*q,c,fn[6];
-
-   /*
-    * Isolate the filename from the path.
-    */
-   q = strrchr(*argv,':');
-   if (q == NULL)
-       q = *argv;
-   else
-       ++q;
-   /*
-    * See if it's the real iconx -- case independent compare.
-    */
-   p = fn;
-   if (strlen(q) == 5)
-      while (c = *q++) *p++ = tolower(c);
-   *p = '\0';
-   if (strcmp(fn,"iconx") != 0) {
-     /*
-      * This technique of shifting arguments relies on the fact that
-      * argv[0] is never referenced, since this will make it invalid.
-      */
-      --argv;
-      ++argc;
-      --(*ip);
+      {
+      char tmp[256], *t2;
+      int len = 0;
+      strcpy(tmp, argv[0]);
+      t2 = tmp;
+      while (*t2) {
+         *t2 = tolower(*t2);
+         t2++;
+         len++;
+         }
+   
       /*
-       * We don't want to look for any command line options in this
-       * case.  They could interfere with options for the icon
-       * program.
+       * if argv[0] is not a reference to our interpreter, take it as the
+       * name of the icode file, and back up for it.
        */
-      NoOptions = 1;
+      #ifdef MSWindows
+         if (!((len == 6 && !strcmp(tmp+len-6, "wiconx")) ||
+               (len > 6 && !strcmp(tmp+len-7, "\\wiconx")) ||
+               (len == 10 && !strcmp(tmp+len-10, "wiconx.exe")) ||
+               (len > 10 && !strcmp(tmp+len-11, "\\wiconx.exe")))) {
+      #else				/* MSWindows */
+         if (!((len == 7 && !strcmp(tmp+len-7, "nticonx")) ||
+               (len > 7 && !strcmp(tmp+len-8, "\\nticonx")) ||
+               (len == 11 && !strcmp(tmp+len-11, "nticonx.exe")) ||
+               (len > 11 && !strcmp(tmp+len-12, "\\nticonx.exe")))) {
+      #endif				/* MSWindows */
+         argv--;
+         argc++;
+         (*ip)--;
+         }
       }
-   }
-#endif					/* MPW */
-#endif                                  /* MACINTOSH */
+   #endif				/* NT */
 
-/*
- * Handle command line options.
-*/
-#if MACINTOSH && MPW
-   if (!NoOptions)
-#endif					/* MACINTOSH && MPW */
+   /*
+    * Handle command line options.
+    */
    while ( argv[1] != 0 && *argv[1] == '-' ) {
       switch ( *(argv[1]+1) ) {
 
-#ifdef TallyOpt
-	/*
-	 * Set tallying flag if -T option given
-	 */
-	case 'T':
-	    tallyopt = 1;
-	    break;
-#endif					/* TallyOpt */
+      #ifdef TallyOpt
+      /*
+       * Set tallying flag if -T option given
+       */
+      case 'T':
+         tallyopt = 1;
+         break;
+      #endif				/* TallyOpt */
 
       /*
        * Set stderr to new file if -e option is given.
@@ -947,9 +621,9 @@ int *ip;
    for (dp = fnames; dp < efnames; dp++)
       StrLoc(*dp) = strcons + (uword)StrLoc(*dp);
 
-#ifdef MultiThread
-   curpstate = savedstate;
-#endif						/* MultiThread */
+   #ifdef MultiThread
+      curpstate = savedstate;
+   #endif				/* MultiThread */
    }
 
 
@@ -1011,10 +685,10 @@ void xmfree()
             free((pointer)xabp);
             }
 
-#ifdef CoProcesses
-         coswitch(BlkLoc(k_current)->coexpr.cstate, xep->cstate, -1);
+         #ifdef CoProcesses
+            coswitch(BlkLoc(k_current)->coexpr.cstate, xep->cstate, -1);
                 /* terminate coproc for coexpression first */
-#endif					/* CoProcesses */
+         #endif				/* CoProcesses */
 
       free((pointer)xep);
       stklist = NULL;
@@ -1022,62 +696,3 @@ void xmfree()
 
    }
 #endif					/* !COMPILER */
-
-
-#ifdef MacGraph
-void MouseInfoInit (void)
-{
-   gMouseInfo.wasDown = false;
-}
-
-void ToolBoxInit (void)
-{
-   InitGraf (&qd.thePort);
-   InitFonts ();
-   InitWindows ();
-   InitMenus ();
-   TEInit ();
-   InitDialogs (nil);
-   InitCursor ();
-}
-
-void MenuBarInit (void)
-{
-   Handle         menuBar;
-   MenuHandle     menu;
-   OSErr          myErr;
-   long           feature;
-
-   menuBar = GetNewMBar (kMenuBar);
-   SetMenuBar (menuBar);
-
-   menu = GetMHandle (kAppleMenu);
-   AddResMenu (menu, 'DRVR');
-
-   DrawMenuBar ();
-}
-
-void EventLoop ( void )
-{
-   EventRecord event, *eventPtr;
-   char theChar;
-
-   gDone = false;
-   while ( gDone == false )
-   {
-      if ( WaitNextEvent ( everyEvent, &event, kSleep, nil ) )
-         DoEvent ( &event );
-   }
-}
-
-void main ()
-{
-   atexit (EventLoop);
-   ToolBoxInit ();
-   MenuBarInit ();
-   MouseInfoInit ();
-   cmlArgs = "";
-
-   EventLoop ();
-}
-#endif					/* MacGraph */
