@@ -94,14 +94,25 @@ operator{*} ! bang(underef x -> dx)
             if ((status & Fs_Read) == 0) 
                runerr(212, dx);
 
-#ifdef StandardLib
+#ifdef ReadDirectory
+            if ((status & Fs_Directory) != 0) {
+               for (;;) {
+                  struct dirent *de = readdir((DIR*) fd);
+                  if (de == NULL)
+                     fail;
+                  slen = strlen(de->d_name);
+                  Protect(sp = alcstr(de->d_name, slen), runerr(0));
+                  suspend string(slen, sp);
+                  }
+               }
+#endif					/* ReadDirectory */
+
             if (status & Fs_Writing) {
                fseek(fd, 0L, SEEK_CUR);
                BlkLoc(dx)->file.status &= ~Fs_Writing;
                }
             BlkLoc(dx)->file.status |= Fs_Reading;
             status = BlkLoc(dx)->file.status;
-#endif					/* StandardLib */
 
             for (;;) {
                StrLen(result) = 0;
@@ -121,10 +132,10 @@ operator{*} ! bang(underef x -> dx)
 
 #ifdef RecordIO
                   if ((slen = (status & Fs_Record ?
-                               getrec(sbuf, MaxCvtLen, fd) :
-                               getstrg(sbuf, MaxCvtLen, fd))) == -1)
+			getrec(sbuf, MaxCvtLen, fd) :
+			getstrg(sbuf, MaxCvtLen, &BlkLoc(dx)->file))) == -1)
 #else					/* RecordIO */
-                  if ((slen = getstrg(sbuf,MaxCvtLen,fd)) == -1)
+                  if ((slen = getstrg(sbuf,MaxCvtLen,&BlkLoc(dx)->file)) == -1)
 #endif                                  /* RecordIO */
 
                      fail;
