@@ -182,6 +182,8 @@ dptr dp1, dp2;
 
       default:
 	 syserr("anycmp: unknown datatype.");
+	 /*NOTREACHED*/
+	 return 0;  /* avoid gcc warning */
       }
    }
 
@@ -207,19 +209,22 @@ dptr dp;
 
       case T_Real:
 	 return 2;
+
+      /* string: return 3 (see above) */
+
       case T_Cset:
 	 return 4;
-      case T_Coexpr:
-	 return 5;
       case T_File:
+	 return 5;
+      case T_Coexpr:
 	 return 6;
       case T_Proc:
 	 return 7;
       case T_List:
 	 return 8;
-      case T_Table:
-	 return 9;
       case T_Set:
+	 return 9;
+      case T_Table:
 	 return 10;
       case T_Record:
 	 return 11;
@@ -227,6 +232,8 @@ dptr dp;
          return 12;
       default:
 	 syserr("order: unknown datatype.");
+	 /*NOTREACHED*/
+	 return 0;  /* avoid gcc warning */
       }
    }
 
